- Changes the signature of `xoutil.names.nameof`:func:, also the semantics of
  the `full` parameter is improved.

  This is the major change in this release.  Actually, this release has being
  prepared in sync with the release 1.5.6 (just a few days ago) to have this
  change passed while still keeping our versions scheme.
